import { Space } from "antd";
import React, { PropsWithChildren, useMemo } from "react";
import DecoratePoint from "./components/decoratePoint";
import styles from "./content.module.css";
import LabelText from "./components/labelText";
import BaseFormComponent from "@/customForm/entity/base";
import { OnlyProperties } from "@/customForm/interfaces";
import { buildListByGroupId } from "@/customForm/utils";

const Title: React.FC<PropsWithChildren> = ({ children }) => {
  return (
    <Space align="center" style={{ marginBottom: 24 }}>
      <DecoratePoint />
      <div className={styles.title}>{children}</div>
    </Space>
  );
};

const Card: React.FC<PropsWithChildren> = ({ children }) => {
  return <div className={styles.card}>{children}</div>;
};
type ContentProps = {
  configSource: any;
  data: any;
};
const Content = (props: ContentProps) => {
  const { configSource, data } = props;

  const config = useMemo(() => {
    const matterContentList = configSource?.matterContentList;
    let groupList = [] as any;
    let configList = [] as any;
    if (matterContentList) {
      const temp = matterContentList.map((item: any) => {
        return {
          ...item,
          componentOption: item.otherSet ? JSON.parse(item.otherSet) : {},
          key: item.fieldKey,
        };
      });
      temp.forEach((item: OnlyProperties<BaseFormComponent>) => {
        if (item.componentType === "Branch") {
          groupList.push(item);
        } else {
          if (
            item.componentType !== "ImgUpload" &&
            item.componentType !== "FileUpload"
          ) {
            configList.push(item);
          }
        }
      });
      return {
        groupList: groupList,
        configList: buildListByGroupId(configList),
      };
    } else
      return {
        groupList: [],
        configList: [],
      };
  }, [configSource]);
  const findValue = (key: string) => {
    const reportContents = data?.reportContents ?? [];
    return reportContents.find((v: any) => v.contentId === key)?.content;
  };
  return (
    <div>
      {config.configList.map((item) => {
        return (
          <div className={styles.group}>
            {item.title && item.title.length > 0 && <Title>{item.title}</Title>}
            <Card>
              {item.list.map((subItem) => {
                const value = findValue(subItem.key);
                if (value) {
                  return (
                    <LabelText
                      label={subItem.label}
                      wrap
                      text={value}
                      labelColor="rgba(139, 146, 159, 1)"
                      textColor="rgba(89, 101, 118, 1)"
                    ></LabelText>
                  );
                }
              })}
            </Card>
          </div>
        );
      })}
    </div>
  );
};

export default Content;
